package com.huimv.manager.exception;

import cn.dustlight.captcha.store.CodeNotExistsException;
import cn.dustlight.captcha.verifier.VerifyFailException;
import com.huimv.manager.enums.AuthExceptionEnum;
import com.huimv.manager.result.R;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.NoHandlerFoundException;

/**
 * 异常处理器
 *
 * @author Mark sunlightcs@gmail.com
 */
@RestControllerAdvice
public class RRExceptionHandler {
	private Logger logger = LoggerFactory.getLogger(getClass());

	/**
	 * 处理自定义异常
	 */
	@ExceptionHandler(RRException.class)
	public R handleRRException(RRException e){
		R r = new R();
		r.put("code", e.getCode());
		r.put("msg", e.getMessage());

		return r;
	}

	@ExceptionHandler(NoHandlerFoundException.class)
	public R handlerNoFoundException(Exception e) {
		logger.error(e.getMessage(), e);
		return R.error(404, "路径不存在，请检查路径是否正确");
	}

	@ExceptionHandler(DuplicateKeyException.class)
	public R handleDuplicateKeyException(DuplicateKeyException e){
		logger.error(e.getMessage(), e);
		return R.error("数据库中已存在该记录");
	}

//	@ExceptionHandler(AuthorizationException.class)
//	public R handleAuthorizationException(AuthorizationException e){
//		logger.error(e.getMessage(), e);
//		return R.error("没有权限，请联系管理员授权");
//	}

	@ExceptionHandler(CodeNotExistsException.class)
	public R handCodeNotExistsException(CodeNotExistsException e){
		logger.error(e.getMessage(),e);
		return R.error(AuthExceptionEnum.CONSTANT_EMPTY_ERROR.getMessage());
	}

	@ExceptionHandler(VerifyFailException.class)
	public R handVerifyFailException(VerifyFailException e){
		logger.error(e.getMessage(), e);
		return R.error(AuthExceptionEnum.CONSTANT_EMPTY_ERROR.getMessage());
	}

	@ExceptionHandler(AuthException.class)
	public R handAuthException(AuthException e){
		logger.error(e.getMessage(), e);
		return R.error(e.getCode(),e.getErrorMessage());
	}

	@ExceptionHandler(Exception.class)
	public R handleException(Exception e){
		logger.error(e.getMessage(), e);
		return R.error();
	}
}
