package com.huimv.manager.interceptor;

import com.alibaba.fastjson.JSONObject;
import com.huimv.manager.enums.AdminTypeEnum;
import com.huimv.manager.modular.entity.MobileUser;
import com.huimv.manager.modular.service.MobileUserService;
import com.huimv.manager.result.R;
import com.huimv.manager.util.JwtUtils;
import io.jsonwebtoken.Claims;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * <p>
 *  jwt拦截器
 * </p>
 * @author yinhao
 * @since 2021/4/19
 */

public class JWTInterceptor implements HandlerInterceptor {

    @Autowired
    private MobileUserService mobileUserService;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        // 如果不是映射到方法，则直接通过
        if (!(handler instanceof HandlerMethod)) {
            return true;
        }

        response.setContentType("application/json;charset=utf-8");
        // 获取token
        String token = request.getHeader("token");
        if (StringUtils.isEmpty(token)) {

            response.getWriter().write(JSONObject.toJSONString(R.error(419,"无token,请先登录!")));
//            response.sendError(419,"无token,请先登录!");
            return false;
        }

        Claims claims = null;
        try {
            claims = JwtUtils.getClaims(token);
        } catch (Exception e) {
            response.getWriter().write(JSONObject.toJSONString(R.error(419,"token信息有误,请检查!")));
            return false;
        }
        Integer id = claims.get("id", Integer.class);
        if (mobileUserService == null) {

            response.getWriter().write(JSONObject.toJSONString(R.error(500,"服务器发送错误!")));
//            response.sendError(500,"服务器发送错误!");
            return false;
        }

        MobileUser mobileUser = mobileUserService.findById(id);
        if (mobileUser == null) {
            response.getWriter().write(JSONObject.toJSONString(R.error(401,"用户不存在,请先注册!")));
//            response.sendError(401,"用户不存在,请先注册!");
            return false;
        }

        if (!mobileUser.getGrantClass().equals(AdminTypeEnum.ADMIN.getCode())) {
            response.getWriter().write(JSONObject.toJSONString(R.error(401,"你不是管理员,不能进行该操作!")));
//            response.sendError(401,"你不是管理员,不能进行该操作!");
            return false;
        }

        int result = JwtUtils.verifyToken(claims);
        if (result >= 1) {
            response.getWriter().write(JSONObject.toJSONString(R.error(419,"token已失效,请重新登录!")));
//            response.sendError(419,"token已失效,请重新登录!");
            return false;
        }
//        if (result == -1) {
//            String jwtToken = JwtUtils.getJwtToken(id);
////            response.getWriter().write(JSONObject.toJSONString(R.ok("token需要刷新").put("code",30000).put("token",jwtToken)));
//            return true;
//        }
        return true;
    }


    @Override
    public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler, ModelAndView modelAndView) throws Exception {

    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler, Exception ex) throws Exception {

    }
}